ctloglists

package module
v1.20260914.151600 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 14, 2026 License: GPL-3.0 Imports: 10 Imported by: 3

README

ctloglists

Tracker for CT Log Lists and logs' Accepted Roots

Features

Versioning

The latest Log Lists and Accepted Roots are fetched hourly by a GitHub Action. Any changes are automatically committed. If one or more Log Lists have been updated, a Release is tagged using a Scalable Calendar Versioning format (v1.YYYYMMDD.HHMMSS).

API

LoadLogLists() error

Loads and parses all bundled CT Log Lists.

LoadAcceptedRoots() error

Loads and parses all bundled Accepted Roots data.

OldestTimestampForLogListWithEnforcementCutOff() time.Time

Returns the oldest LogListTimestamp among the supported log lists that are known to have a corresponding 70-day enforcement cut-off (Chrome, Apple, Mozilla). Log lists with an omitted or zero timestamp are ignored.

Exported Variables
Variable Description
GstaticV3All Chrome's all_logs_list.json
AppleCurrent Apple's current_log_list.json
CrtshV3All crt.sh all logs
CrtshV3Active crt.sh active logs
MozillaV3Known Mozilla's known_logs_list.json
BimiV3Approved BIMI approved_logs_list.json
LogMimics Chrome log mimics
LogSignatureVerifierMap Map of log ID → signature verifier
TemporalIntervalMap Map of log ID → temporal interval
AcceptedRootsMap Map of roots list hash → PEM cert pool
LogAcceptedRootsMap Map of log ID → accepted roots list hash

Used by

Documentation

Index

Constants

This section is empty.

Variables

var AcceptedRootsMap map[[sha256.Size]byte]*x509util.PEMCertPool
var GstaticV3All, AppleCurrent, CrtshV3All, CrtshV3Active, MozillaV3Known, BimiV3Approved, LogMimics *loglist3.LogList
var LogAcceptedRootsMap map[[sha256.Size]byte][sha256.Size]byte
var LogSignatureVerifierMap map[[sha256.Size]byte]*ctgo.SignatureVerifier
var TemporalIntervalMap map[[sha256.Size]byte]*loglist3.TemporalInterval

Functions

func LoadAcceptedRoots

func LoadAcceptedRoots() error

func LoadLogLists

func LoadLogLists() error

func OldestTimestampForLogListWithEnforcementCutOff added in v1.20260701.151600

func OldestTimestampForLogListWithEnforcementCutOff() time.Time

OldestTimestampForLogListWithEnforcementCutOff returns the oldest LogListTimestamp among the supported log lists that are known to have a corresponding 70-day enforcement cut-off.

Types

This section is empty.

Directories

Path Synopsis
cmd
acceptedroots command
diffloglists command

Jump to